@@ -18,7 +18,7 @@ DO_MYSQL_DBNAME=test
 DO_MYSQL_DATABASE=/${DO_MYSQL_DBNAME}
 
 mysql_install_db --no-defaults --datadir=${MYTEMP_DIR} --force --skip-name-resolve --user=${DO_MYSQL_USER}
-/usr/sbin/mysqld --no-defaults --user=${DO_MYSQL_USER} --socket=${MYSQL_UNIX_PORT} --datadir=${MYTEMP_DIR} --skip-networking --skip-grant &
+/usr/sbin/mysqld --no-defaults --user=${DO_MYSQL_USER} --socket=${MYSQL_UNIX_PORT} --datadir=${MYTEMP_DIR} --skip-networking --local-infile=1 --skip-grant &
 echo -n pinging mysqld.
 attempts=0
 while ! /usr/bin/mysqladmin --socket=${MYSQL_UNIX_PORT} ping ; do
@@ -36,4 +36,4 @@ cleanup() {
 }
 trap cleanup INT EXIT TERM
 
-"$@"
+$@ || exit $?
